@@ -2,7 +2,7 @@
 function(object, ..., beta = FALSE,
 	#method = c("0", "NA"), method.var = c("NA", "0"),
 	rank = NULL, rank.args = NULL, revised.var = TRUE) {
-	
+
 	if (isTRUE("method" %in% names(match.call())))
 		stop("the argument 'method' is no longer accepted")
 
@@ -41,7 +41,13 @@ function(object, ..., beta = FALSE,
 	all.terms <- all.terms[order(vapply(gregexpr(":", all.terms),
 		function(x) if(x[1L] == -1L) 0L else length(x), numeric(1L)), all.terms)]
 
-	all.model.names <- .makeModelNames(models, all.terms)
+	# all.model.names <- modelNames(models, asNumeric = FALSE,
+		# withRandomTerms = FALSE, withFamily = FALSE)
+
+	all.model.names <- modelNames(allTerms = allterms1, uqTerms = all.terms)
+
+
+	#if(is.null(names(models))) names(models) <- all.model.names
 
 	# check if models are unique:
 	mcoeffs <- lapply(models, coeffs)
@@ -51,23 +57,24 @@ function(object, ..., beta = FALSE,
 
 	if (ndups > 0L) {
 		stop("Models are not unique. Duplicates: ",
-			paste(sapply(dup, paste, sep="", collapse=" = "),
+			paste(sapply(dup, paste, sep = "", collapse = " = "),
 				if(ndups > 1L) c(rep(", ", ndups - 2L), ", and ", "") else NULL,
-				collapse="", sep=""))
+				collapse = "", sep = ""))
 	}
 
 	# workaround for different behavior of model.matrix with lme: data argument is required
-	if(any(linherits(models, c(lme=TRUE)))) {
-		model.matrix.lme <- function(object, data=object$data, ...)
-			model.matrix.default(object, data=data, ...)
+	if(any(linherits(models, c(lme = TRUE)))) {
+		model.matrix.lme <- function(object, data = object$data, ...)
+			model.matrix.default(object, data = data, ...)
 	}
 
-	ic <- vapply(models, rank, numeric(1))
-	dev <- if (!is.null(tryCatch(deviance(models[[1L]]), error=.fnull)))
-		vapply(models, deviance, numeric(1)) else NA
+	ic <- vapply(models, rank, numeric(1L))
+	#dev <- if (!is.null(tryCatch(deviance(models[[1L]]), error = .fnull)))
+		#vapply(models, deviance, numeric(1L)) else NA
+	ll <- vapply(models, logLik, numeric(1L))
 	delta <- ic - min(ic)
 	weight <- exp(-delta / 2) / sum(exp(-delta / 2))
-	model.order <- order(weight, decreasing=TRUE)
+	model.order <- order(weight, decreasing = TRUE)
 
 	# DEBUG:
 	# sapply(sapply(sapply(models[model.order], coef), names), paste, collapse="+")
@@ -76,14 +83,13 @@ function(object, ..., beta = FALSE,
 	# ----!!! From now on, everything MUST BE ORDERED by 'weight' !!!-----------
 
 	selection.table <- data.frame(
-		Deviance = dev,	IC = ic, Delta = delta, Weight = weight,
+		logLik = ll, IC = ic, Delta = delta, Weight = weight,
 		row.names = all.model.names
 	)[model.order, ]
 
 	weight <- selection.table$Weight # has been sorted in table
 	models <- models[model.order]
 
-
 	all.par <- unique(names(unlist(mcoeffs)))
 	#all.par <- unique(unlist(lapply(models, function(m) names(coeffs(m)))))
 	all.par <- all.par[order(vapply(gregexpr(":", all.par),
@@ -115,7 +121,6 @@ function(object, ..., beta = FALSE,
 		names = c(paste(rep(c("Coef","SE", "DF"), each = npar), all.par, sep = ".")))
 	)) ### << mtable
 
-
 	all.coef <- mtable[, seq_len(npar)] 	# mtable is already sorted by weigth
 	all.se <- mtable[, npar + seq_len(npar)]
 	all.df <- mtable[, 2L * npar + seq_len(npar)]
@@ -132,7 +137,7 @@ function(object, ..., beta = FALSE,
 
 	importance <- apply(weight * p, 2L, sum)
 	names(importance) <- all.terms
-	importance <- sort(importance, decreasing=TRUE)
+	importance <- sort(importance, decreasing = TRUE)
 
 	#if (method == "0")
 	missing.par <- is.na(all.coef)
@@ -168,7 +173,7 @@ function(object, ..., beta = FALSE,
 	#mmx <- gmm[, cnmmxx[match(colnames(gmm), cnmmxx, nomatch = 0)]]
 
 	mmxs <- tryCatch(cbindDataFrameList(lapply(models, model.matrix)),
-					 error=.fnull)
+					 error = .fnull)
 
 	# Far less efficient:
 	#mmxs <- lapply(models, model.matrix)
@@ -178,9 +183,9 @@ function(object, ..., beta = FALSE,
 
 	# residuals averaged (with brute force)
 	rsd <- tryCatch(apply(vapply(models, residuals, residuals(object)), 1L,
-		weighted.mean, w=weight), error=.fnull)
-	trm <- tryCatch(terms(models[[1]]),
-			error=function(e) terms(formula(models[[1L]])))
+		weighted.mean, w = weight), error = .fnull)
+	trm <- tryCatch(terms(models[[1L]]),
+			error = function(e) terms(formula(models[[1L]])))
 	frm <- reformulate(all.terms,
 				response = attr(trm, "variables")[-1L][[attr(trm, "response")]])
 
@@ -190,7 +195,8 @@ function(object, ..., beta = FALSE,
 		summary = selection.table,
 		coefficients = all.coef,
 		se = all.se,
-		variable.codes = all.terms,
+		variable.codes2 = all.terms,
+		variable.codes = attr(all.model.names, "variables"),
 		avg.model = avg.model,
 		coef.shrinkage = coef.shrink,
 		importance = importance,
@@ -219,14 +225,14 @@ function(object, full = FALSE, ...) if(full) object$coef.shrinkage else
 # TODO: predict type="response" + average on response scale
 `predict.averaging` <-
 function(object, newdata = NULL, se.fit = FALSE, interval = NULL,
-	type = c("link", "response"), full = FALSE, ...) {
+	type = c("link", "response"), full = TRUE, ...) {
 
 	type <- match.arg(type)
 	if (!missing(interval)) .NotYetUsed("interval", error = FALSE)
 
 	models <- attr(object, "mList")
 
-	# Benchmark: vapply is ~4x faster !
+	# Benchmark: vapply is ~4x faster
 	#system.time(for(i in 1:1000) sapply(models, inherits, what="gam")) /
 	#system.time(for(i in 1:1000) vapply(models, inherits, logical(1L), what="gam"))
 
@@ -247,7 +253,7 @@ function(object, newdata = NULL, se.fit = FALSE, interval = NULL,
 			Xnew <- model.matrix(tt, data = newdata, xlev = xlev)
 		}
 
-		Xnew <- Xnew[, match(names(coeff), colnames(Xnew), nomatch = 0)]
+		Xnew <- Xnew[, match(names(coeff), colnames(Xnew), nomatch = 0L)]
 		ret <- (Xnew %*% coeff)[, 1L]
 
 		#if (se.fit) {
@@ -257,9 +263,10 @@ function(object, newdata = NULL, se.fit = FALSE, interval = NULL,
 		#	return(list(fit = y, se.fit = se))
 		#}
 	} else {
-		# DebugPrint("brute force")
 		# otherwise, use brute force:
 
+		if(full == FALSE) warning("argument 'full' ignored")
+
 		#pred <- if(!missing(newdata))
 		#	lapply(models, predict, newdata = newdata, se.fit = se.fit,...) else
 		#	lapply(models, predict, se.fit = se.fit, ...)
@@ -281,7 +288,7 @@ function(object, newdata = NULL, se.fit = FALSE, interval = NULL,
 			lapply(pred[err], warning)
 			stop(sprintf(ngettext(sum(err), "'predict' for model %s caused error",
 				"'predict' for models %s caused errors"),
-				paste(sQuote(names(models[err])), collapse=", ")))
+				paste(sQuote(names(models[err])), collapse = ", ")))
 		}
 
 
@@ -300,12 +307,12 @@ function(object, newdata = NULL, se.fit = FALSE, interval = NULL,
 			# TODO: ase!
 			#no.ase <- all(is.na(object$avg.model[,3]))
 			# if(no.ase) 2 else 3
-			ret <- list(fit=apred[1L, ], se.fit=apred[2L, ])
+			ret <- list(fit = apred[1L, ], se.fit = apred[2L, ])
 
 			if (type == "response") {
 				fam <- tryCatch(vapply(models, function(z)
-					unlist(family(z)[c("family", "link")]), character(2)),
-								error=function(e) NULL)
+					unlist(family(z)[c("family", "link")]), character(2L)),
+								error = function(e) NULL)
 
 				if(!is.null(fam)) {
 					if(any(fam[,1] != fam[, -1L]))
@@ -321,7 +328,7 @@ function(object, newdata = NULL, se.fit = FALSE, interval = NULL,
 				w = object$summary$Weight)
 		} else {
 			stop("'predict' method for the component models returned",
-				 " a value in an unrecognised format")
+				 " a value in unrecognised format")
 		}
 	}
 	return(ret)
@@ -374,12 +381,13 @@ function (object, parm, level = 0.95, ...) {
 function (x, digits = max(3L, getOption("digits") - 3L),
     signif.stars = getOption("show.signif.stars"), ...) {
 
-    cat("\nCall:  ", paste(deparse(x$call), sep = "\n", collapse = "\n"),
+    cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), 
         "\n\n", sep = "")
 
-    cat("\nModel summary:\n")
+    cat("Component models:\n")
 	print(round(as.matrix(x$summary), 2L), na.print="")
 
+	#cat("\nVariable names abbreviations:\n")
 	cat("\nVariables:\n")
 	print(x$variable.codes, quote=FALSE)
 
@@ -398,7 +406,7 @@ function (x, digits = max(3L, getOption("digits") - 3L),
 	#	"0"="taken to be zero", "NA"="excluded"), "\n")
 
 
-	cat("\nFull model-averaged coefficients:", "\n")
+	cat("\nFull model-averaged coefficients (with shrinkage):", "\n")
 	printCoefmat(matrix(x$coef.shrink, nrow=1L, dimnames =list("", x$term.names)),
 		P.values=FALSE, has.Pvalue=FALSE, cs.ind=seq_along(x$term.names),
 		tst.ind=NULL)
@@ -414,7 +422,7 @@ function (x, digits = max(3L, getOption("digits") - 3L),
 
 `print.averaging` <-
 function(x, ...) {
-    cat("\nCall:  ", paste(deparse(x$call), sep = "\n", collapse = "\n"),
+    cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), 
         "\n\n", sep = "")
     cat("Component models:", "\n")
 	comp.names <- rownames(x$summary)
