@@ -11,6 +11,16 @@ function(model, ...) {
     return(cbind(`Estimate`=cf, `Std. Error` = se))
 }
 
+`tTable.glmmML` <- function(model, ...) {
+    coef <- model$coefficients
+    se <- model$coef.sd
+    ret <- cbind(coef, se, coef/se, signif(1 - pchisq((coef/se)^2,
+        1)))
+    dimnames(ret) <- list(names(coef), c("Estimate", "Std. Error",
+        "z", "Pr(>|z|)"))
+  return(ret)
+}
+
 `tTable.gls` <-
 function (model, ...) return(summary(model)$tTable)
 
@@ -18,10 +28,7 @@ function (model, ...) return(summary(model)$tTable)
 function(model, ...) return(summary(model)$tTable)
 
 
-# these are for old versions of lme4
 `tTable.mer` <-
-#`tTable.glmer` <-
-# `tTable.lmer` <-
 function(model, ...) {
 	#sm <- eval(expression(summary), as.environment("package:lme4"))
 	sm <- eval(expression(summary), asNamespace("lme4"))
@@ -29,6 +36,13 @@ function(model, ...) {
 	#return((summary(model))@coefs)
 }
 
+`tTable.multinom` <-
+function(model, ...) {
+	ret <- do.call("cbind", summary(model)[c("coefficients", "standard.errors")])
+	colnames(ret) <- c("Estimate", "Std. Error")
+	return(ret)
+}
+
 `tTable.sarlm` <-
 `tTable.spautolm` <-
 function(model, ...) {
@@ -37,13 +51,12 @@ function(model, ...) {
 	return(cbind(`Estimate`=cf, `Std. Error` = se))
 }
 
-
-`tTable.multinom` <-
-function(model, ...) {
-	ret <- do.call("cbind", summary(model)[c("coefficients", "standard.errors")])
-	colnames(ret) <- c("Estimate", "Std. Error")
-	return(ret)
+`tTable.survreg` <- function (model, ...) {
+	return(cbind(
+		`Estimate` = model$coefficients,
+		`Std. Error` = sqrt(diag(model$var)))
+	)
 }
 
 `tTable.coxph` <- function (model, ...)
-	return(summary(model)$coefficients[,-c(2, 3), drop=FALSE])
+	return(summary(model)$coefficients[,-c(2L, 3L), drop = FALSE])
\ No newline at end of file
